pub fn register_flowgraph_layout<C: FlowGraphLayout>(
name: &str,
custom: C,
) -> (&'static C, CoreFlowGraphLayout)Expand description
Registers a custom FlowGraphLayout, this allows you to customize the layout of flow graphs.
pub fn register_flowgraph_layout<C: FlowGraphLayout>(
name: &str,
custom: C,
) -> (&'static C, CoreFlowGraphLayout)Registers a custom FlowGraphLayout, this allows you to customize the layout of flow graphs.