pub struct FlowGraphLayoutRequest { /* private fields */ }Expand description
Represents a queued flow graph layout request, given out by FlowGraph::request_layout.
Implementations
Sourceimpl FlowGraphLayoutRequest
impl FlowGraphLayoutRequest
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Returns true if the layout request has completed.
Sourcepub fn abort(&self)
pub fn abort(&self)
Removes the request from the flow graphs layout queue, and sets FlowGraph::is_layout_complete